@@ -25,4 +25,4 @@ class Severity(Enum):
     @property
     def icon(self) -> str:
         """Get emoji icon for the severity level."""
-        return {"error": "❌", "warning": "⚠️", "info": "ℹ️"}[self.value]
+        return {"error": "[ERROR]", "warning": "[WARNING]", "info": "[INFO]"}[self.value]
