@@ -170,11 +170,19 @@ class BaseRule(ABC):
 
     def get_text_from_node(self, node: Any, content: str) -> str:
         """Extract text content from a tree-sitter node."""
-        return content[node.start_byte : node.end_byte]
+        # Tree-sitter uses byte offsets, but Python strings use character offsets
+        # We need to convert byte offsets to character offsets for UTF-8 content
+        content_bytes = content.encode('utf-8')
+        node_bytes = content_bytes[node.start_byte : node.end_byte]
+        return node_bytes.decode('utf-8', errors='replace')
 
     def get_line_from_byte(self, byte_offset: int, content: str) -> int:
         """Convert byte offset to line number (1-indexed)."""
-        return content[:byte_offset].count("\n") + 1
+        # Tree-sitter uses byte offsets, we need to handle UTF-8 properly
+        content_bytes = content.encode('utf-8')
+        bytes_before = content_bytes[:byte_offset]
+        text_before = bytes_before.decode('utf-8', errors='replace')
+        return text_before.count("\n") + 1
 
     def get_line(self, content: str, line_num: int) -> str:
         """Get a specific line from content (1-indexed)."""
@@ -550,6 +558,98 @@ class ASTRule(BaseRule):
     # -------------------------------
     #  Name-extraction helpers
     # -------------------------------
+    def _get_function_name(self, func_node: Any, content: str) -> str:
+        """Extract function name from AST node."""
+        try:
+            # Try multiple strategies to find function name
+
+            # Strategy 1: Look for function_declarator child
+            for child in func_node.children:
+                if child.type == "function_declarator":
+                    # Check for operator overload - look at all children before parameter_list
+                    operator_name = None
+                    for subchild in child.children:
+                        if subchild.type == "parameter_list":
+                            break
+                        # Tree-sitter may represent operator as "operator" node or as a sequence
+                        if subchild.type in ("operator", "operator_name"):
+                            operator_text = self.get_text_from_node(subchild, content).strip()
+                            # Remove any trailing parenthesis
+                            operator_text = operator_text.rstrip('(').strip()
+                            return operator_text
+                    
+                    # Regular function - look for identifier
+                    for subchild in child.children:
+                        if subchild.type == "identifier":
+                            return self.get_text_from_node(subchild, content)
+
+            # Strategy 2: Look for direct identifier children
+            for child in func_node.children:
+                if child.type == "identifier":
+                    return self.get_text_from_node(child, content)
+
+            # Strategy 3: Parse the text directly to extract function name (This is what is used generally)
+            func_text = self.get_text_from_node(func_node, content)
+            lines = func_text.split("\n")
+            for line in lines:
+                # Look for function declaration patterns
+                import re
+
+                # Check for operator overload first (before cleaning)
+                # Match: operator followed by operator symbols, but stop before opening paren
+                operator_match = re.search(r'\boperator\s*([+\-*/=<>!&|^%~\[\]]+)\s*\(', line)
+                if operator_match:
+                    return f"operator{operator_match.group(1)}"
+                
+                # Also handle operator() and similar cases
+                operator_paren_match = re.search(r'\boperator\s*(\(\)|\[\])\s*\(', line)
+                if operator_paren_match:
+                    return f"operator{operator_paren_match.group(1)}"
+
+                # Clean up the line - remove attributes and qualifiers
+                clean_line = line.strip()
+                clean_line = re.sub(
+                    r"\[\[.*?\]\]", "", clean_line
+                )  # Remove [[nodiscard]] etc
+                clean_line = re.sub(r"\bvirtual\b", "", clean_line)
+                clean_line = re.sub(r"\bstatic\b", "", clean_line)
+                clean_line = re.sub(r"\bconst\b", "", clean_line)
+                clean_line = re.sub(r"\binline\b", "", clean_line)
+                clean_line = re.sub(r"\bexplicit\b", "", clean_line)
+                clean_line = re.sub(r"\boverride\b", "", clean_line)
+                clean_line = re.sub(r"\bfinal\b", "", clean_line)
+
+                # Try multiple patterns to find function name
+                patterns = [
+                    r"(?:std::)?(?:\w+)?\s+(\w+)\s*\(",  # return_type name(
+                    r"(\w+)\s*\(",  # Simple name(
+                ]
+
+                for pattern in patterns:
+                    match = re.search(pattern, clean_line)
+                    if match:
+                        potential_name = match.group(1)
+                        # Skip common type keywords
+                        if potential_name not in [
+                            "string",
+                            "int",
+                            "bool",
+                            "void",
+                            "auto",
+                            "size_t",
+                            "uint32_t",
+                            "shared_ptr",
+                            "unique_ptr",
+                            "vector",
+                            "map",
+                            "set",
+                            "char",
+                        ]:
+                            return potential_name
+
+            return "unknown"
+        except Exception:
+            return "unknown"
 
     def extract_function_name(self, func_node: Any, content: str) -> str:
         """Return the unqualified function name for a declaration/definition."""
@@ -558,6 +658,29 @@ class ASTRule(BaseRule):
             # – the first identifier there is the function name.
             for child in func_node.children:
                 if child.type == "function_declarator":
+                    # Check for operator overload first using regex on the text
+                    func_text = self.get_text_from_node(child, content)
+                    import re
+                    
+                    # Match: operator followed by operator symbols, but stop before opening paren
+                    operator_match = re.search(r'\boperator\s*([+\-*/=<>!&|^%~\[\]]+)\s*\(', func_text)
+                    if operator_match:
+                        return f"operator{operator_match.group(1)}"
+                    
+                    # Also handle operator() and similar cases
+                    operator_paren_match = re.search(r'\boperator\s*(\(\)|\[\])\s*\(', func_text)
+                    if operator_paren_match:
+                        return f"operator{operator_paren_match.group(1)}"
+                    
+                    # Check for operator overload via AST nodes
+                    for grand in child.children:
+                        if grand.type in ("operator", "operator_name"):
+                            # Get the full operator text (e.g., "operator=", "operator+", etc.)
+                            operator_text = self.get_text_from_node(grand, content)
+                            # Clean up: remove any trailing opening parenthesis that might have been captured
+                            operator_text = operator_text.strip().rstrip('(').strip()
+                            return operator_text
+                    
                     # Sequential scan until parameter_list; the last identifier
                     # encountered before the parameter list is the function
                     # name (per C++ grammar).
@@ -588,6 +711,44 @@ class ASTRule(BaseRule):
             pass
         return "unknown"
 
+    def _get_doxygen_comment(self, class_node: Any, content: str) -> str:
+        """Get Doxygen comment before class."""
+        try:
+            class_start_line = class_node.start_point[0]
+            lines = content.split("\n")
+
+            comment_lines = []
+            in_comment = False
+
+            # Look at lines before the class, searching backwards for the closest comment
+            for i in range(
+                class_start_line - 1, max(0, class_start_line - 50) - 1, -1
+            ):
+                if i < len(lines):
+                    line = lines[i].strip()
+                    if "*/" in line:
+                        if not in_comment:
+                            in_comment = True
+                            comment_lines.insert(0, line)
+                        else:
+                            comment_lines.insert(0, line)
+                            break
+                    elif in_comment:
+                        comment_lines.insert(0, line)
+                        if "/**" in line:
+                            break
+                    elif line == "":
+                        # Empty line - continue looking
+                        continue
+                    else:
+                        # Non-empty, non-comment line - stop looking
+                        break
+
+            return "\n".join(comment_lines)
+        except Exception:
+            return ""
+
+
     # -------------------------------
     #  Parameter helpers
     # -------------------------------
@@ -598,15 +759,16 @@ class ASTRule(BaseRule):
         """Return a list of parameter identifiers for *func_node*."""
         names: list[str] = []
         try:
-            # Locate the parameter_list node.
+            # Locate the function_declarator node (may be nested in pointer_declarator)
+            func_declarator = self._find_function_declarator(func_node)
+            if not func_declarator:
+                return names
+
+            # Find the parameter_list
             param_list = None
-            for child in func_node.children:
-                if child.type == "function_declarator":
-                    for grand in child.children:
-                        if grand.type == "parameter_list":
-                            param_list = grand
-                            break
-                if param_list:
+            for child in func_declarator.children:
+                if child.type == "parameter_list":
+                    param_list = child
                     break
 
             if not param_list:
@@ -623,15 +785,91 @@ class ASTRule(BaseRule):
                 stack = list(param.children)
                 while stack:
                     node = stack.pop()
+                    # Skip attribute nodes (like [[maybe_unused]]) to avoid capturing attribute identifiers
+                    if node.type in ("attribute_declaration", "attribute_specifier", "attribute"):
+                        continue
                     if node.type == "identifier":
                         last_id = self.get_text_from_node(node, content)
-                    stack.extend(node.children)
+                    # Only traverse children if not an attribute node
+                    if node.type not in ("attribute_declaration", "attribute_specifier", "attribute"):
+                        stack.extend(node.children)
                 if last_id:
                     names.append(last_id)
         except Exception:
             pass
         return names
 
+    def has_unnamed_parameters(self, func_node: Any, content: str) -> bool:
+        """Check if function has any unnamed parameters (parameters with type but no name).
+        
+        In C++, parameters can be declared without names (e.g., void foo(int) { }), 
+        which is common for unused parameters in overrides.
+        """
+        try:
+            # Locate the function_declarator node
+            func_declarator = self._find_function_declarator(func_node)
+            if not func_declarator:
+                return False
+
+            # Find the parameter_list
+            param_list = None
+            for child in func_declarator.children:
+                if child.type == "parameter_list":
+                    param_list = child
+                    break
+
+            if not param_list:
+                return False
+
+            # Check each parameter declaration
+            for param in param_list.children:
+                if param.type not in (
+                    "parameter_declaration",
+                    "optional_parameter_declaration",
+                ):
+                    continue
+                
+                # Check if this parameter has an identifier (name)
+                has_identifier = False
+                stack = list(param.children)
+                while stack:
+                    node = stack.pop()
+                    # Skip attribute nodes
+                    if node.type in ("attribute_declaration", "attribute_specifier", "attribute"):
+                        continue
+                    if node.type == "identifier":
+                        # Check if this identifier is a type or a parameter name
+                        # Type identifiers are typically children of type_identifier, qualified_identifier, etc.
+                        # Parameter names are typically direct children of parameter_declaration
+                        # A simple heuristic: if we find any identifier at the "parameter name" position, 
+                        # the parameter is named
+                        has_identifier = True
+                        break
+                    if node.type not in ("attribute_declaration", "attribute_specifier", "attribute"):
+                        stack.extend(node.children)
+                
+                # If we found a parameter declaration but no identifier was found, it's unnamed
+                if not has_identifier:
+                    return True
+            
+            return False
+        except Exception:
+            return False
+
+    def _find_function_declarator(self, node: Any) -> Any:
+        """Recursively find function_declarator node.
+        
+        function_declarator may be nested inside pointer_declarator or reference_declarator
+        when the function returns a pointer or reference.
+        """
+        if node.type == "function_declarator":
+            return node
+        for child in node.children:
+            result = self._find_function_declarator(child)
+            if result:
+                return result
+        return None
+
     # -------------------------------
     #  Comment helpers
     # -------------------------------
