@@ -108,24 +108,33 @@ class IncludeOrderWrongRule(RegexRule):
         if len(group) < 2:
             return
 
-        paths = [item[1] for item in group]
+        # Filter out lines that should be skipped due to NOLINT directives
+        filtered_group = []
+        for item in group:
+            line_num = item[0]
+            line_content = self.get_line(content, line_num)
+            
+            # Check if this line should be skipped due to NOLINT directives
+            if self.should_skip_line(line_content, str(self.rule_id)):
+                continue
+            
+            # Check if next line skip applies
+            should_skip_next, skip_rules = self.should_skip_next_line(content, line_num)
+            if should_skip_next and (skip_rules == "all" or str(self.rule_id) in skip_rules):
+                continue
+                
+            filtered_group.append(item)
+
+        if len(filtered_group) < 2:
+            return
+
+        paths = [item[1] for item in filtered_group]
         sorted_paths = sorted(paths)
 
         if paths != sorted_paths:
             for i, path in enumerate(paths):
                 if path != sorted_paths[i]:
-                    line_num = group[i][0]
-                    
-                    # Check if this line should be skipped due to NOLINT directives
-                    line_content = self.get_line(content, line_num)
-                    if self.should_skip_line(line_content, str(self.rule_id)):
-                        continue
-                    
-                    # Check if next line skip applies
-                    should_skip_next, skip_rules = self.should_skip_next_line(content, line_num)
-                    if should_skip_next and (skip_rules == "all" or str(self.rule_id) in skip_rules):
-                        continue
-                    
+                    line_num = filtered_group[i][0]
                     self.add_issue(
                         file_path=file_path,
                         line_number=line_num,
@@ -266,8 +275,6 @@ class IncludeOrderWrongRule(RegexRule):
     def _get_include_category(self, include_path: str, is_system: bool, file_path: str = "") -> str:
         """Determine the category of an include."""
         # Check for precompiled headers first
-        if "NOLINT" in include_path:
-            return "skipped"
         if self._is_precompiled_header(include_path):
             return "precompiled"
 
