@@ -373,6 +373,12 @@ class ModernMissingConstRule(ASTRule):
         if self._returns_void(func_node, content):
             return False
 
+        # Check if the method body modifies member variables
+        # This is a simple heuristic - if we see assignments to members, it's not a const-safe getter
+        func_text = self.get_text_from_node(func_node, content)
+        if self._appears_to_modify_state(func_text):
+            return False
+
         getter_prefixes = {
             "get",
             "is",
@@ -391,6 +397,31 @@ class ModernMissingConstRule(ASTRule):
             return True
 
         return False
+    
+    def _appears_to_modify_state(self, func_text: str) -> bool:
+        """Check if function appears to modify member state."""
+        # Look for patterns that suggest state modification
+        # This is a heuristic - not perfect but catches common cases
+        
+        # Check for member variable modifications (e.g., member_ = value, member_ += value)
+        import re
+        
+        # Pattern for member variable assignment (members usually end with _)
+        if re.search(r'\b\w+_\s*[+\-*/]?=', func_text):
+            return True
+        
+        # Check for increment/decrement of members
+        if re.search(r'(\+\+|--)\s*\w+_|\w+_\s*(\+\+|--)', func_text):
+            return True
+        
+        # Check for method calls that likely modify state
+        modifying_methods = ['push', 'pop', 'insert', 'erase', 'clear', 'resize', 'reserve',
+                             'Read', 'Write', 'Append', 'Update', 'Modify']
+        for method in modifying_methods:
+            if f'.{method}(' in func_text or f'->{method}(' in func_text or f'{method}<' in func_text:
+                return True
+        
+        return False
 
     def _returns_void(self, func_node: Any, content: str) -> bool:
         """Check if function returns void."""
