@@ -450,24 +450,37 @@ class NamingClassCaseRule(ASTRule):
 
         for class_node in class_nodes:
             class_name = self._get_class_name(class_node, content)
+            node_type = class_node.type
             if (
                 class_name
-                and not self._should_skip_class(class_name)
+                and not self._should_skip_class(class_name, node_type)
                 and not self._is_valid_camelcase(class_name)
             ):
                 line_num = self.get_line_from_byte(
                     class_node.start_byte, content
                 )
+                if self.should_skip_line(self.get_line(content, line_num), str(self.rule_id)) or self.should_skip_next_line(content, line_num)[0]:
+                    continue
                 self.add_issue(
                     file_path=file_path,
                     line_number=line_num,
                     column=1,
-                    message=f"Class '{class_name}' should use CamelCase (e.g., 'MyClass')",
+                    message=f"{self._get_node_type(node_type)} '{class_name}' should use CamelCase (e.g., 'MyClass')",
                     suggested_fix=self._to_camelcase(class_name),
                 )
 
         return self.issues
 
+    def _get_node_type(self, node_type: str) -> str:
+        """Get the node type in a human readable format."""
+        if node_type == "class_specifier":
+            return "Class"
+        elif node_type == "struct_specifier":
+            return "Struct"
+        elif node_type == "enum_specifier":
+            return "Enum"
+        return node_type
+
     def _get_class_name(self, class_node: Any, content: str) -> str:
         """Extract class name from class node."""
         for child in class_node.children:
@@ -475,7 +488,7 @@ class NamingClassCaseRule(ASTRule):
                 return self.get_text_from_node(child, content)
         return ""
 
-    def _should_skip_class(self, class_name: str) -> bool:
+    def _should_skip_class(self, class_name: str, node_type: str) -> bool:
         """Check if class should be skipped from naming checks."""
         # Skip system types and POSIX types
         system_types = {
@@ -1143,119 +1156,6 @@ class NamingEnumValueCaseRule(ASTRule):
             success=False, message="No enum value names could be fixed"
         )
 
-
-class NamingStructCaseRule(ASTRule):
-    """Rule to enforce CamelCase for struct names."""
-
-    def check(
-        self, file_path: str, content: str, tree: Any, config: Any
-    ) -> List[LintIssue]:
-        self.issues = []
-
-        # Find struct declarations
-        struct_nodes = self.find_nodes_by_types(tree, ["struct_specifier"])
-
-        for struct_node in struct_nodes:
-            struct_name = self._get_struct_name(struct_node, content)
-            if (
-                struct_name
-                and not self._should_skip_struct(struct_name)
-                and not self._is_valid_camelcase(struct_name)
-            ):
-                line_num = self.get_line_from_byte(
-                    struct_node.start_byte, content
-                )
-                expected_name = self._to_camelcase(struct_name)
-                self.add_issue(
-                    file_path=file_path,
-                    line_number=line_num,
-                    column=1,
-                    message=f"Struct '{struct_name}' should use CamelCase (e.g., '{expected_name}')",
-                    suggested_fix=expected_name,
-                )
-
-        return self.issues
-
-    def _get_struct_name(self, struct_node: Any, content: str) -> str:
-        """Extract struct name from struct node."""
-        for child in struct_node.children:
-            if child.type == "type_identifier":
-                return self.get_text_from_node(child, content)
-        return ""
-
-    def _should_skip_struct(self, struct_name: str) -> bool:
-        """Check if struct should be skipped from naming checks."""
-        # Skip system types and POSIX types
-        system_types = {
-            "sockaddr",
-            "sockaddr_in",
-            "sockaddr_un",
-            "in_addr",
-            "hostent",
-            "servent",
-            "protoent",
-            "stat",
-            "dirent",
-            "FILE",
-            "DIR",
-            "pthread_t",
-            "pthread_mutex_t",
-            "pthread_cond_t",
-            "sigaction",
-            "sigset_t",
-            "timespec",
-            "timeval",
-            "fd_set",
-            "pollfd",
-            "epoll_event",
-        }
-
-        # Skip if it's a known system type
-        if struct_name in system_types:
-            return True
-
-        # Skip template parameter types (single uppercase letters)
-        if len(struct_name) == 1 and struct_name.isupper():
-            return True
-
-        return False
-
-    def _is_valid_camelcase(self, name: str) -> bool:
-        """Check if name follows CamelCase convention."""
-        if not name:
-            return False
-
-        # Should start with capital letter (PascalCase)
-        if not name[0].isupper():
-            return False
-
-        # Should not have underscores
-        if "_" in name.strip("_"):
-            return False
-
-        # Should not be all uppercase (that's not CamelCase)
-        if name.isupper():
-            return False
-
-        # Should not be all lowercase (that's not CamelCase)
-        if name.islower():
-            return False
-
-        # Must contain at least one lowercase letter to be proper CamelCase
-        if not any(c.islower() for c in name):
-            return False
-
-        return True
-
-    def _to_camelcase(self, name: str) -> str:
-        """Convert to CamelCase."""
-        if "_" in name:
-            parts = name.split("_")
-            return "".join(part.capitalize() for part in parts if part)
-        else:
-            return name.capitalize()
-
-
 class NamingMemberCaseRule(ASTRule):
     """Rule to enforce snake_case_ (with trailing underscore) for member variables."""
 
