@@ -556,27 +556,6 @@ RULE_DEFINITIONS = {
             "enum sequence_status { Waiting, Running };  // Should be UPPER_CASE",
         ],
     ),
-    RuleId.NAMING_STRUCT_CASE: RuleDefinition(
-        rule_id=RuleId.NAMING_STRUCT_CASE,
-        name="Struct Naming Case",
-        description="Structs should use CamelCase naming",
-        severity=Severity.ERROR,
-        category="naming",
-        style_guide_section="§5.1 - Type Naming",
-        rationale="Consistent with class naming conventions",
-        requires_ast=True,
-        auto_fixable=True,
-        performance_impact="low",
-        false_positive_risk="low",
-        good_examples=[
-            "struct SequenceConfig { std::int32_t max_length; };",
-            "struct Point { std::int32_t x, y; };",
-        ],
-        bad_examples=[
-            "struct sequence_config { std::int32_t max_length; };  // Should be CamelCase",
-            "struct point { std::int32_t x, y; };  // Should be CamelCase",
-        ],
-    ),
     RuleId.NAMING_MEMBER_CASE: RuleDefinition(
         rule_id=RuleId.NAMING_MEMBER_CASE,
         name="Member Variable Naming",
