@@ -5,7 +5,7 @@ Test suite for the C++ Linter.
 This test file provides comprehensive coverage for:
 1. Core components (Severity, Issue, Config, Engine)
 2. Rule registry and management
-3. All 49 individual linter rules
+3. All 48 individual linter rules
 4. CLI functionality
 5. Integration scenarios
 """
@@ -105,9 +105,9 @@ class TestCoreComponents(LinterTestCase):
         self.assertEqual(str(Severity.WARNING), "warning")
         self.assertEqual(str(Severity.INFO), "info")
 
-        self.assertEqual(Severity.ERROR.icon, "❌")
-        self.assertEqual(Severity.WARNING.icon, "⚠️")
-        self.assertEqual(Severity.INFO.icon, "ℹ️")
+        self.assertEqual(Severity.ERROR.icon, "[ERROR]")
+        self.assertEqual(Severity.WARNING.icon, "[WARNING]")
+        self.assertEqual(Severity.INFO.icon, "[INFO]")
 
     def test_lint_issue_creation(self):
         """Test LintIssue data structure."""
@@ -178,10 +178,10 @@ class TestRuleRegistry(LinterTestCase):
     """Test the rule registry system."""
 
     def test_all_plugin_rules_defined(self):
-        """Verify that exactly 49 rules are defined in RuleId enum."""
+        """Verify that exactly 48 rules are defined in RuleId enum."""
         all_rules = list(RuleId)
         self.assertEqual(
-            len(all_rules), 49, f"Expected 49 rules, but found {len(all_rules)}"
+            len(all_rules), 48, f"Expected 48 rules, but found {len(all_rules)}"
         )
 
     def test_rule_categories(self):
@@ -285,9 +285,9 @@ class TestNamingRules(LinterTestCase):
         self.assertIn(RuleId.NAMING_CLASS_CASE, list(RuleId))
 
     def test_all_naming_rules_exist(self):
-        """Verify all 10 naming rules exist."""
+        """Verify all 9 naming rules exist."""
         naming_rules = [r for r in RuleId if r.name.startswith("NAMING_")]
-        self.assertEqual(len(naming_rules), 10)  # 10 NAMING_ rules
+        self.assertEqual(len(naming_rules), 9)  # 10 NAMING_ rules
 
 
 @pytest.mark.unit
